Module tool

Module tool 

Tool trait: functions that agents can invoke.

Structs

ToolDefinition
A tool definition: metadata sent to the LLM so it knows what tools are available and how to call them.
Toolbox
A collection of tools available to an agent.

Traits

Tool
A tool that an agent can call during reasoning.