pub struct Toolbox<T: Tool> { /* private fields */ }Expand description
A collection of tools available to an agent.
Generic over the tool type T to avoid dyn Trait.
All tools in a toolbox must be the same concrete type.
For heterogeneous tools, use an enum that implements Tool.
ⓘ
enum MyTools {
Calculator(Calculator),
WebSearch(WebSearch),
}
impl Tool for MyTools {
fn definition(&self) -> ToolDefinition {
match self {
Self::Calculator(t) => t.definition(),
Self::WebSearch(t) => t.definition(),
}
}
fn call(&self, args: Value) -> Io<Error, Value> {
match self {
Self::Calculator(t) => t.call(args),
Self::WebSearch(t) => t.call(args),
}
}
}Implementations